import marshmallow as ma

from .data_type import DataTypeSchema
from .schema_version_checker import verify_schema_version

_PATH_RE = "^[/~\\$\\*\\?\\[].*$"


class PathRestrictionsSchema(ma.Schema):
    _DATA_TYPE = "path_restrictions#1.0.0"
    DATA_TYPE = ma.fields.String(required=True, allow_none=False, default=_DATA_TYPE)

    read = ma.fields.List(ma.fields.String(validate=[ma.validate.Regexp(_PATH_RE)]))
    read_write = ma.fields.List(
        ma.fields.String(validate=[ma.validate.Regexp(_PATH_RE)])
    )
    none = ma.fields.List(ma.fields.String(validate=[ma.validate.Regexp(_PATH_RE)]))

    @ma.validates("DATA_TYPE")
    def validate_data_type(self, data, **kwargs):
        verify_schema_version(data, self._DATA_TYPE)


path_restrictions_schema = PathRestrictionsSchema()
DataTypeSchema.register_schema(path_restrictions_schema)
