import click
import logging
import os


@click.group()
@click.option('--debug/--no-debug', default=False)
@click.option(
    "--environment", "-e",
    help="""Override the target environment and the GLOBUS_SDK_ENVIRONMENT environment 
variable for the installer with this parameter""",
    default=None
)
@click.pass_context
def cli(ctx: dict, debug: bool, environment: str):
    # ensure that ctx.obj exists and is a dict (in case `cli()` is called
    # by means other than the `if` block below)
    ctx.ensure_object(dict)

    ctx.obj['DEBUG'] = debug
    ctx.obj['ENVIRONMENT'] = environment \
        if environment is not None else os.environ.get("GLOBUS_SDK_ENVIRONMENT", "default")
    os.environ['GLOBUS_SDK_ENVIRONMENT'] = ctx.obj['ENVIRONMENT']
    logging.basicConfig(level=logging.DEBUG if debug else logging.INFO)